@@ -3,10 +3,12 @@ use 5.008_001;
 use strict;
 use warnings FATAL => 'all';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Config ();
 
+our $VERBOSE;
+
 # modules which dosn't exist in CPAN
 our %IGNORE = map { $_ => 1 } (
     'Encode/ConfigLocal.pm',
@@ -29,7 +31,12 @@ sub lib::xi::INC {
 
     return if $IGNORE{$file};
 
-    if(system($^X, '-S', $self->cpanm_command, $file) == 0) {
+    my @cmd = ($^X, '-S', $self->cpanm_command, $file);
+    if($VERBOSE) {
+        print STDERR "# PERL_CPANM_OPT: ", ($ENV{PERL_CPANM_OPT} || '') ,"\n";
+        print STDERR "# COMMAND: @cmd\n";
+    }
+    if(system(@cmd) == 0) {
         foreach my $lib (@{ $self->{myinc} }) {
             if(open my $inh, '<', "$lib/$file") {
                 $INC{$file} = "$lib/$file";
@@ -69,6 +76,8 @@ sub import {
         unshift @cpanm_opts, '-l', $install_dir;
     }
 
+    $VERBOSE = scalar grep { $_ eq '-v' } @cpanm_opts;
+
     push @INC, $class->new(
         install_dir => $install_dir,
         myinc       => $install_dir ? \@myinc : \@INC,
@@ -88,7 +97,7 @@ lib::xi - Installs missing modules on demand
 
 =head1 VERSION
 
-This document describes lib::xi version 0.10.
+This document describes lib::xi version 0.11.
 
 =head1 SYNOPSIS
 
